re-frame.vertica.react


component-argumentscljs

(component-arguments fiber)
source

component-namecljs

(component-name fiber)
source

component-tagscljs

source

direct-reagent-ownercljs

(direct-reagent-owner element)

Return the nearest Reagent owner when element is a host root emitted by that component. Crossing another host fiber means the element is only a DOM descendant of the component, not one of its rendered roots.

Return the nearest Reagent owner when element is a host root emitted by that
component. Crossing another host fiber means the element is only a DOM
descendant of the component, not one of its rendered roots.
sourceraw docstring

element-labelcljs

(element-label element)
source

fiber-for-elementcljs

(fiber-for-element element)
source

host-tagscljs

source

nearest-reagent-root-elementcljs

(nearest-reagent-root-element element)
source

next-idcljs

source

normalize-component-namecljs

(normalize-component-name value)
source

object-idcljs

(object-id prefix object)
source

object-idscljs

source

owning-componentscljs

(owning-components element)
(owning-components element limit)
source

react-majorcljs

(react-major)
source

reagent-root-element?cljs

(reagent-root-element? element)
source

render-reactioncljs

(render-reaction fiber)
source

supported-react?cljs

(supported-react?)
source

cljdoc builds & hosts documentation for Clojure/Script libraries