re-frame.vertica.shared


association-pathclj/s

(association-path path)

Encode a provenance path without losing keyword namespaces through clj->js. Strings are printed as EDN too, so the wildcard sentinel cannot collide with an app-db string containing the same text.

Encode a provenance path without losing keyword namespaces through clj->js.
Strings are printed as EDN too, so the wildcard sentinel cannot collide with
an app-db string containing the same text.
sourceraw docstring

association-wildcardclj/s

source

bounded-previewclj/s

(bounded-preview value)
(bounded-preview value limit)
source

deterministic-graphclj/s

(deterministic-graph nodes edges)
source

layer-orderclj/s

source

leaf-pathsclj/s

(leaf-paths paths)

Remove a path when a more specific proven path exists. Wildcard descendants remain concrete provenance and therefore also supersede their parent.

Remove a path when a more specific proven path exists. Wildcard descendants
remain concrete provenance and therefore also supersede their parent.
sourceraw docstring

path-labelclj/s

(path-label path)
source

path-prefix?clj/s

(path-prefix? prefix path)
source

protocol-versionclj/s

source

stable-idclj/s

(stable-id kind value)
source

value-previewclj/s

(value-preview value limit)
source

value-stringclj/s

(value-string value)
source

wildcardclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries