(replay computation app-db query-v dyn-v)Replay a pure layer-2 computation against read-tracking collections. Returns all proven paths even when the computation throws.
Replay a pure layer-2 computation against read-tracking collections. Returns all proven paths even when the computation throws.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |