(direct-reagent-owner element)Return the nearest Reagent owner when element is a host root emitted by that component. Crossing another host fiber means the element is only a DOM descendant of the component, not one of its rendered roots.
Return the nearest Reagent owner when element is a host root emitted by that component. Crossing another host fiber means the element is only a DOM descendant of the component, not one of its rendered roots.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |