(association-path path)Encode a provenance path without losing keyword namespaces through clj->js. Strings are printed as EDN too, so the wildcard sentinel cannot collide with an app-db string containing the same text.
Encode a provenance path without losing keyword namespaces through clj->js. Strings are printed as EDN too, so the wildcard sentinel cannot collide with an app-db string containing the same text.
(leaf-paths paths)Remove a path when a more specific proven path exists. Wildcard descendants remain concrete provenance and therefore also supersede their parent.
Remove a path when a more specific proven path exists. Wildcard descendants remain concrete provenance and therefore also supersede their parent.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |